@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2017-2020 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2017-2021 -- leonerd@leonerd.org.uk
 
 use v5.26;
-use Object::Pad 0.19;
+use Object::Pad 0.57;
 
-package Device::Chip::PCF8575 0.03;
+package Device::Chip::PCF8575 0.04;
 class Device::Chip::PCF8575
-   extends Device::Chip::PCF857x;
+   :isa(Device::Chip::PCF857x);
 
 =encoding UTF-8
 
